@@ -74,6 +74,11 @@ main (int    argc,
   /* set the program name */
   g_set_prgname (G_LOG_DOMAIN);
 
+#ifdef DEBUG
+  /* if something doesn't work, fix your code instead! */
+  g_log_set_always_fatal (G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING);
+#endif
+
   /* set the application name. Translators: Don't translate "Tumbler". */
   g_set_application_name (_("Tumbler Thumbnailing Service"));
 
@@ -99,22 +104,6 @@ main (int    argc,
   /* create the lifecycle manager */
   lifecycle_manager = tumbler_lifecycle_manager_new ();
 
-  /* create the thumbnail cache service */
-  cache_service = tumbler_cache_service_new (connection, lifecycle_manager);
-
-  /* try to start the service and exit if that fails */
-  if (!tumbler_cache_service_start (cache_service, &error))
-    {
-      g_warning (_("Failed to start the thumbnail cache service: %s"), error->message);
-      g_error_free (error);
-
-      g_object_unref (cache_service);
-
-      dbus_g_connection_unref (connection);
-
-      return EXIT_FAILURE;
-    }
-
   /* create the thumbnailer registry */
   registry = tumbler_registry_new ();
 
@@ -152,6 +141,15 @@ main (int    argc,
   /* update the URI schemes / MIME types supported information */
   tumbler_registry_update_supported (registry);
 
+  /* create the thumbnail cache service */
+  cache_service = tumbler_cache_service_new (connection, lifecycle_manager);
+
+  /* create the thumbnailer manager service */
+  manager = tumbler_manager_new (connection, lifecycle_manager, registry);
+
+  /* create the generic thumbnailer service */
+  service = tumbler_service_new (connection, lifecycle_manager, registry);
+
   /* try to load specialized thumbnailers and exit if that fails */
   if (!tumbler_registry_load (registry, &error))
     {
@@ -159,16 +157,32 @@ main (int    argc,
                  error->message);
       g_error_free (error);
 
-      g_object_unref (registry);
+      g_object_unref (service);
+      g_object_unref (manager);
       g_object_unref (cache_service);
+      g_object_unref (registry);
 
       dbus_g_connection_unref (connection);
 
       return EXIT_FAILURE;
     }
 
-  /* create the thumbnailer manager service */
-  manager = tumbler_manager_new (connection, lifecycle_manager, registry);
+  /* try to start the service and exit if that fails */
+  if (!tumbler_cache_service_start (cache_service, &error))
+    {
+      g_warning (_("Failed to start the thumbnail cache service: %s"), error->message);
+      g_error_free (error);
+
+      g_object_unref (service);
+      g_object_unref (manager);
+      g_object_unref (cache_service);
+      g_object_unref (registry);
+
+      dbus_g_connection_unref (connection);
+
+      /* service already running, exit gracefully to not break clients */
+      return EXIT_SUCCESS;
+    }
 
   /* try to start the service and exit if that fails */
   if (!tumbler_manager_start (manager, &error))
@@ -176,18 +190,17 @@ main (int    argc,
       g_warning (_("Failed to start the thumbnailer manager: %s"), error->message);
       g_error_free (error);
 
+      g_object_unref (service);
       g_object_unref (manager);
-      g_object_unref (registry);
       g_object_unref (cache_service);
+      g_object_unref (registry);
 
       dbus_g_connection_unref (connection);
 
-      return EXIT_FAILURE;
+      /* service already running, exit gracefully to not break clients */
+      return EXIT_SUCCESS;
     }
 
-  /* create the generic thumbnailer service */
-  service = tumbler_service_new (connection, lifecycle_manager, registry);
-
   /* try to start the service and exit if that fails */
   if (!tumbler_service_start (service, &error))
     {
@@ -196,12 +209,13 @@ main (int    argc,
 
       g_object_unref (service);
       g_object_unref (manager);
-      g_object_unref (registry);
       g_object_unref (cache_service);
+      g_object_unref (registry);
 
       dbus_g_connection_unref (connection);
 
-      return EXIT_FAILURE;
+      /* service already running, exit gracefully to not break clients */
+      return EXIT_SUCCESS;
     }
 
   /* create a new main loop */
@@ -220,8 +234,8 @@ main (int    argc,
   /* shut our services down and release all objects */
   g_object_unref (service);
   g_object_unref (manager);
-  g_object_unref (registry);
   g_object_unref (cache_service);
+  g_object_unref (registry);
   g_object_unref (lifecycle_manager);
 
   /* disconnect from the D-Bus session bus */
