@@ -63,6 +63,7 @@ typedef struct _ThumbnailerInfo ThumbnailerInfo;
 
 
 
+static void             tumbler_manager_constructed       (GObject          *object);
 static void             tumbler_manager_finalize          (GObject          *object);
 static void             tumbler_manager_get_property      (GObject          *object,
                                                            guint             prop_id,
@@ -158,6 +159,7 @@ tumbler_manager_class_init (TumblerManagerClass *klass)
   GObjectClass *gobject_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
+  gobject_class->constructed = tumbler_manager_constructed;
   gobject_class->finalize = tumbler_manager_finalize; 
   gobject_class->get_property = tumbler_manager_get_property;
   gobject_class->set_property = tumbler_manager_set_property;
@@ -198,6 +200,25 @@ tumbler_manager_init (TumblerManager *manager)
 
 
 
+
+
+static void
+tumbler_manager_constructed (GObject *object)
+{
+  TumblerManager *manager = TUMBLER_MANAGER (object);
+
+  /* everything's fine, install the manager type D-Bus info */
+  dbus_g_object_type_install_info (G_OBJECT_TYPE (manager), 
+                                   &dbus_glib_tumbler_manager_object_info);
+
+  /* register the manager instance as a handler of the manager interface */
+  dbus_g_connection_register_g_object (manager->connection, 
+                                       "/org/freedesktop/thumbnails/Manager1", 
+                                       G_OBJECT (manager));
+}
+
+
+
 static void
 tumbler_manager_finalize (GObject *object)
 {
@@ -1819,7 +1840,6 @@ tumbler_manager_start (TumblerManager *manager,
                        GError        **error)
 {
   DBusConnection *connection;
-  DBusError       dbus_error;
   gint            result;
 
   g_return_val_if_fail (TUMBLER_IS_MANAGER (manager), FALSE);
@@ -1827,28 +1847,17 @@ tumbler_manager_start (TumblerManager *manager,
 
   g_mutex_lock (manager->mutex);
 
-  /* initialize the D-Bus error */
-  dbus_error_init (&dbus_error);
-
   /* get the native D-Bus connection */
   connection = dbus_g_connection_get_connection (manager->connection);
 
   /* request ownership for the manager interface */
   result = dbus_bus_request_name (connection, "org.freedesktop.thumbnails.Manager1",
-                                  DBUS_NAME_FLAG_DO_NOT_QUEUE, &dbus_error);
+                                  DBUS_NAME_FLAG_DO_NOT_QUEUE, NULL);
 
   /* check if that failed */
   if (result != DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER)
     {
-      /* propagate the D-Bus error */
-      if (dbus_error_is_set (&dbus_error))
-        {
-          if (error != NULL)
-            dbus_set_g_error (error, &dbus_error);
-
-          dbus_error_free (&dbus_error);
-        }
-      else if (error != NULL)
+      if (error != NULL)
         {
           g_set_error (error, DBUS_GERROR, DBUS_GERROR_FAILED,
                        _("Another thumbnailer manager is already running"));
@@ -1860,15 +1869,6 @@ tumbler_manager_start (TumblerManager *manager,
       return FALSE;
     }
 
-  /* everything's fine, install the manager type D-Bus info */
-  dbus_g_object_type_install_info (G_OBJECT_TYPE (manager), 
-                                   &dbus_glib_tumbler_manager_object_info);
-
-  /* register the manager instance as a handler of the manager interface */
-  dbus_g_connection_register_g_object (manager->connection, 
-                                       "/org/freedesktop/thumbnails/Manager1", 
-                                       G_OBJECT (manager));
-
   g_mutex_unlock (manager->mutex);
 
   /* load thumbnailers installed into the system permanently */
